3.1.7. biosimulators_utils.lems package — BioSimulators utils 0.1.81 documentation

# 3.1.7. biosimulators_utils.lems package

## 3.1.7.1. Submodules

## 3.1.7.2. biosimulators_utils.lems.validation module

Utilities for validating LEMS models

Author

  Jonathan Karr <karr@mssm.edu>

Date

  2021-06-03

Copyright

  2021, Center for Reproducible Biomedical Modeling

License

  MIT

biosimulators_utils.lems.validation.validate_model(filename, name=None)

  Check that a model is valid

  Parameters

    - filename (`str`) – path to model

    - name (`str`, optional) – name of model for use in error messages

  Returns

    - nested `list` of `str`: nested list of errors (e.g., required ids missing or ids not unique)

    - nested `list` of `str`: nested list of errors (e.g., required ids missing or ids not unique)

  Return type

    `tuple`